<?php

namespace Drupal\cforge\EventSubscriber;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Migration modifications
 */
class MigrationSubscriber implements EventSubscriberInterface {

  const FILTER_FORMATS = [
    'editor_full_html' => 'full_html',
    'editor_filtered_html' => 'basic',
    'filtered' => 'basic',
    'full' => 'basic'
  ];


  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
       //AKA Drupal\migrate\Event\MigrateEvents::PRE_IMPORT
       'migrate.pre_row_save' => [['migratePreRowSave']]
    ];
  }

  /**
   * @param Drupal\migrate\Event\MigratePreRowSave $event
   */
  public function migratePreRowSave($event) {
    $row = $event->getRow();
    $migration = $event->getMigration();

    if($row->getSourceProperty('plugin') == 'd7_user') {
      // Rename the fields
      $map = [
        'manage_notes' => 'notes_admin',
        'profile_notes' => 'notes',//this isn't on the WestieLETS source
        'profile_phones' => 'phones',
        'profile_address' => 'address'
      ];
      foreach ($map as $old_name => $new_name) {
        if ($row->hasDestinationProperty($old_name)) {
          $row->setDestinationProperty($new_name, $row->getDestinationProperty($old_name));
          $row->removeDestinationProperty($old_name);
        }
      }
    }
    if($migration->id() == 'd7_node' or $migration->id() == 'd7_mcapi_transaction') {
      if ($row->hasDestinationProperty('offers_wants_categories')) {
        $entity_type = $row->getSourceProperty('entity_type');
        $new_field_name = $row->getSourceProperty('entity_type') == 'node' ? 'categories' : 'category';
        $row->setDestinationProperty($new_field_name, $row->getSourceProperty('offers_wants_categories'));
        $row->removeDestinationProperty('offers_wants_categories');
      }
    }
    if($row->getSourceProperty('plugin') == 'd7_comment') {
      if ($row->getSourceProperty('field_name') == 'comment_body') {
echo "\nChanging comment_body field instance from ".$row->getSourceProperty('field_name')." to bundle 'node'";
         $row->setDestinationProperty('bundle', 'node');// Assumes no comments on transactions
      }
    }

    // Change the filter format for every body field
    // I don't know why this doesn't happen already
    if($row->getSourceProperty('plugin') == 'd7_node') { //what about d7_comment?
      if ($bods = $row->getDestinationProperty('body')) {
        $map = static::FILTER_FORMATS;
        foreach ($bods as $delta => &$body) {
          $bods[$delta]['format'] = $map[$body['format']];
        }
        $row->setDestinationProperty('body', $bods);
      }
    }
    if ($migration->getDestinationPlugin() instanceOf \Drupal\migrate\Plugin\migrate\destination\EntityConfigBase) {

    }
  }

}
